@@ -20,7 +20,7 @@ def do_coverage(args):
     
     cov.stop()
     cov.save()
-    cov_dir = os.path.join( neurounits.locations.Locations.get_package_root(), 'out/coverage/' )
+    cov_dir = os.path.expanduser('~/.neurounits/.coverage/')
     
     if os.path.exists(cov_dir):
         shutil.rmtree(cov_dir)
@@ -29,4 +29,4 @@ def do_coverage(args):
         os.makedirs(cov_dir)
     cov.html_report(directory=cov_dir)
     
-    print 'Coverage run finished, output in: ', cov_dir
\ No newline at end of file
+    print 'Coverage run finished, output in: ', cov_dir
